@@ -27,9 +27,10 @@ namespace OCA\Mail\Migration;
 
 use Closure;
 use OCP\DB\ISchemaWrapper;
+use OCP\DB\Types;
 use OCP\IDBConnection;
-use OCP\Migration\SimpleMigrationStep;
 use OCP\Migration\IOutput;
+use OCP\Migration\SimpleMigrationStep;
 
 class Version0161Date20190902114635 extends SimpleMigrationStep {
 	/** @var IDBConnection */
@@ -51,7 +52,7 @@ class Version0161Date20190902114635 extends SimpleMigrationStep {
 		$schema = $schemaClosure();
 
 		$mailboxTable = $schema->getTable('mail_mailboxes');
-		$mailboxTable->addColumn('special_use', 'string', [
+		$mailboxTable->addColumn('special_use', Types::STRING, [
 			'length' => 255,
 			'default' => '[]',
 		]);
@@ -68,6 +69,6 @@ class Version0161Date20190902114635 extends SimpleMigrationStep {
 		$update->update('mail_accounts')
 			->set('last_mailbox_sync', $update->createNamedParameter(0));
 
-		$update->execute();
+		$update->executeStatement();
 	}
 }
